@@ -6,14 +6,19 @@ test -z "$srcdir" && srcdir=.
 
 PKG_NAME="mate-user-share"
 
-(test -f $srcdir/configure.in) || {
+(test -f $srcdir/configure.ac) || {
     echo -n "**Error**: Directory "\`$srcdir\'" does not look like the"
     echo " top level $PKG_NAME directory"
     exit 1
 }
 
 which mate-autogen || {
-    echo "You need to install mate-common from the MATE Git"
+    echo "You need to install mate-common"
+    exit 1
+}
+
+which yelp-build || {
+    echo "You need to install yelp-tools"
     exit 1
 }
 
